"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Literal
from typing_extensions import TypedDict


IntegrationStateChangedWebhookPayloadType = Literal["integration-state-changed",]
r"""Type of the webhook event"""


IntegrationStateChangedWebhookPayloadIntegrationCategory = Literal[
    "HRIS",
    "ATS",
    "ASSESSMENT",
    "LMS",
]
r"""The category of the integration (HRIS, ATS, ASSESSMENT, or LMS)."""


class IntegrationStateChangedWebhookPayloadEndUserTypedDict(TypedDict):
    r"""Information about the end user who created the integration."""

    organization_name: str
    r"""The name of the organization that owns the integration."""
    creator_email: Nullable[str]
    r"""The email address of the user who created the integration."""
    origin_id: Nullable[str]
    r"""The unique identifier of the organization in the integrated system."""


class IntegrationStateChangedWebhookPayloadEndUser(BaseModel):
    r"""Information about the end user who created the integration."""

    organization_name: str
    r"""The name of the organization that owns the integration."""

    creator_email: Nullable[str]
    r"""The email address of the user who created the integration."""

    origin_id: Nullable[str]
    r"""The unique identifier of the organization in the integrated system."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


QaStatus = Literal[
    "PENDING",
    "FAILED",
    "PASSED",
]
r"""The quality assurance status of the integration."""


IntegrationStateChangedWebhookPayloadSetupStatus = Literal[
    "INCOMPLETE",
    "FINAL_SYNC_PENDING",
    "COMPLETED",
]
r"""The current status of an integration that has filtering, field mapping features or required setup steps."""


State = Literal[
    "ACTIVE",
    "INVALID",
    "INACTIVE",
]
r"""The current state of the integration."""


class IntegrationStateChangedWebhookPayloadDataTypedDict(TypedDict):
    integration_tool: str
    r"""The name of the integrated tool (e.g., \"personio\", \"greenhouse\")."""
    integration_id: str
    r"""The unique identifier of the integration."""
    integration_category: IntegrationStateChangedWebhookPayloadIntegrationCategory
    r"""The category of the integration (HRIS, ATS, ASSESSMENT, or LMS)."""
    end_user: IntegrationStateChangedWebhookPayloadEndUserTypedDict
    r"""Information about the end user who created the integration."""
    qa_status: QaStatus
    r"""The quality assurance status of the integration."""
    setup_status: IntegrationStateChangedWebhookPayloadSetupStatus
    r"""The current status of an integration that has filtering, field mapping features or required setup steps."""
    state: State
    r"""The current state of the integration."""
    updated_at: datetime
    r"""ISO 8601 timestamp when the integration state was last updated."""


class IntegrationStateChangedWebhookPayloadData(BaseModel):
    integration_tool: str
    r"""The name of the integrated tool (e.g., \"personio\", \"greenhouse\")."""

    integration_id: str
    r"""The unique identifier of the integration."""

    integration_category: IntegrationStateChangedWebhookPayloadIntegrationCategory
    r"""The category of the integration (HRIS, ATS, ASSESSMENT, or LMS)."""

    end_user: IntegrationStateChangedWebhookPayloadEndUser
    r"""Information about the end user who created the integration."""

    qa_status: QaStatus
    r"""The quality assurance status of the integration."""

    setup_status: IntegrationStateChangedWebhookPayloadSetupStatus
    r"""The current status of an integration that has filtering, field mapping features or required setup steps."""

    state: State
    r"""The current state of the integration."""

    updated_at: datetime
    r"""ISO 8601 timestamp when the integration state was last updated."""


class IntegrationStateChangedWebhookPayloadTypedDict(TypedDict):
    id: str
    r"""Unique identifier for this webhook event"""
    type: IntegrationStateChangedWebhookPayloadType
    r"""Type of the webhook event"""
    data: IntegrationStateChangedWebhookPayloadDataTypedDict


class IntegrationStateChangedWebhookPayload(BaseModel):
    id: str
    r"""Unique identifier for this webhook event"""

    type: IntegrationStateChangedWebhookPayloadType
    r"""Type of the webhook event"""

    data: IntegrationStateChangedWebhookPayloadData



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .postatsjobsjobidapplicationsrequestbody import (
    PostAtsJobsJobIDApplicationsRequestBody,
    PostAtsJobsJobIDApplicationsRequestBodyTypedDict,
)
from kombo.types import BaseModel, UNSET_SENTINEL
from kombo.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PostAtsJobsJobIDApplicationsGlobalsTypedDict(TypedDict):
    integration_id: NotRequired[str]
    r"""ID of the integration you want to interact with."""


class PostAtsJobsJobIDApplicationsGlobals(BaseModel):
    integration_id: Annotated[
        Optional[str],
        pydantic.Field(alias="X-Integration-Id"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""ID of the integration you want to interact with."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["integration_id"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostAtsJobsJobIDApplicationsRequestTypedDict(TypedDict):
    job_id: str
    r"""The Kombo ID or Remote ID of the Job this candidate should apply for. If you want to use the ID of the integrated system (remote_id) you need to prefix the id with \"remote:\". You can use the remote ID if you do not want to sync jobs."""
    body: PostAtsJobsJobIDApplicationsRequestBodyTypedDict
    r"""POST /ats/jobs/:job_id/applications Request body"""


class PostAtsJobsJobIDApplicationsRequest(BaseModel):
    job_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The Kombo ID or Remote ID of the Job this candidate should apply for. If you want to use the ID of the integrated system (remote_id) you need to prefix the id with \"remote:\". You can use the remote ID if you do not want to sync jobs."""

    body: Annotated[
        PostAtsJobsJobIDApplicationsRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""POST /ats/jobs/:job_id/applications Request body"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from kombo.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


PostForceSyncPositiveResponseType = Literal[
    "FULL",
    "DELTA",
]
r"""The type of the triggered sync. May differ from request, if the integration does not support delta syncs or if another sync is already running."""


class PostForceSyncPositiveResponseDataTypedDict(TypedDict):
    already_queued: bool
    r"""We only allow 1 concurrent sync to be running or queued."""
    sync_id: str
    r"""ID of the newly-created or already-queued-or-running sync."""
    type: PostForceSyncPositiveResponseType
    r"""The type of the triggered sync. May differ from request, if the integration does not support delta syncs or if another sync is already running."""


class PostForceSyncPositiveResponseData(BaseModel):
    already_queued: bool
    r"""We only allow 1 concurrent sync to be running or queued."""

    sync_id: str
    r"""ID of the newly-created or already-queued-or-running sync."""

    type: PostForceSyncPositiveResponseType
    r"""The type of the triggered sync. May differ from request, if the integration does not support delta syncs or if another sync is already running."""


class PostForceSyncPositiveResponseTypedDict(TypedDict):
    data: PostForceSyncPositiveResponseDataTypedDict
    status: Literal["success"]


class PostForceSyncPositiveResponse(BaseModel):
    data: PostForceSyncPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    PostForceSyncPositiveResponse.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PostAtsCandidatesCandidateIDTagsRequestBodyTagTypedDict(TypedDict):
    name: str
    r"""The name of the tag you would like to add. We will automatically find the matching ID of the tag in the system."""


class PostAtsCandidatesCandidateIDTagsRequestBodyTag(BaseModel):
    name: str
    r"""The name of the tag you would like to add. We will automatically find the matching ID of the tag in the system."""


class PostAtsCandidatesCandidateIDTagsRequestBodyPostHeadersTypedDict(TypedDict):
    r"""Headers we will pass with `POST` requests to Greenhouse."""

    on_behalf_of: NotRequired[Nullable[str]]
    r"""ID of the the user that will show up as having performed the action in Greenhouse. We already pass a value by default, but you can use this to override it."""


class PostAtsCandidatesCandidateIDTagsRequestBodyPostHeaders(BaseModel):
    r"""Headers we will pass with `POST` requests to Greenhouse."""

    on_behalf_of: Annotated[
        OptionalNullable[str], pydantic.Field(alias="On-Behalf-Of")
    ] = UNSET
    r"""ID of the the user that will show up as having performed the action in Greenhouse. We already pass a value by default, but you can use this to override it."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["On-Behalf-Of"])
        nullable_fields = set(["On-Behalf-Of"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class PostAtsCandidatesCandidateIDTagsRequestBodyGreenhouseTypedDict(TypedDict):
    r"""Fields specific to Greenhouse."""

    post_headers: NotRequired[
        PostAtsCandidatesCandidateIDTagsRequestBodyPostHeadersTypedDict
    ]
    r"""Headers we will pass with `POST` requests to Greenhouse."""


class PostAtsCandidatesCandidateIDTagsRequestBodyGreenhouse(BaseModel):
    r"""Fields specific to Greenhouse."""

    post_headers: Optional[PostAtsCandidatesCandidateIDTagsRequestBodyPostHeaders] = (
        None
    )
    r"""Headers we will pass with `POST` requests to Greenhouse."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["post_headers"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostAtsCandidatesCandidateIDTagsRequestBodyWorkableTypedDict(TypedDict):
    r"""Workable specific remote fields for ATS actions."""

    on_behalf_of_user_remote_id: NotRequired[str]
    r"""The remote ID of the user that will be displayed in the UI as the one that performed the action."""


class PostAtsCandidatesCandidateIDTagsRequestBodyWorkable(BaseModel):
    r"""Workable specific remote fields for ATS actions."""

    on_behalf_of_user_remote_id: Optional[str] = None
    r"""The remote ID of the user that will be displayed in the UI as the one that performed the action."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["on_behalf_of_user_remote_id"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostAtsCandidatesCandidateIDTagsRequestBodyRemoteFieldsTypedDict(TypedDict):
    r"""Additional fields that we will pass through to specific ATS systems."""

    greenhouse: NotRequired[
        PostAtsCandidatesCandidateIDTagsRequestBodyGreenhouseTypedDict
    ]
    r"""Fields specific to Greenhouse."""
    workable: NotRequired[PostAtsCandidatesCandidateIDTagsRequestBodyWorkableTypedDict]
    r"""Workable specific remote fields for ATS actions."""


class PostAtsCandidatesCandidateIDTagsRequestBodyRemoteFields(BaseModel):
    r"""Additional fields that we will pass through to specific ATS systems."""

    greenhouse: Optional[PostAtsCandidatesCandidateIDTagsRequestBodyGreenhouse] = None
    r"""Fields specific to Greenhouse."""

    workable: Optional[PostAtsCandidatesCandidateIDTagsRequestBodyWorkable] = None
    r"""Workable specific remote fields for ATS actions."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["greenhouse", "workable"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostAtsCandidatesCandidateIDTagsRequestBodyTypedDict(TypedDict):
    tag: PostAtsCandidatesCandidateIDTagsRequestBodyTagTypedDict
    remote_fields: NotRequired[
        PostAtsCandidatesCandidateIDTagsRequestBodyRemoteFieldsTypedDict
    ]
    r"""Additional fields that we will pass through to specific ATS systems."""


class PostAtsCandidatesCandidateIDTagsRequestBody(BaseModel):
    tag: PostAtsCandidatesCandidateIDTagsRequestBodyTag

    remote_fields: Optional[PostAtsCandidatesCandidateIDTagsRequestBodyRemoteFields] = (
        None
    )
    r"""Additional fields that we will pass through to specific ATS systems."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["remote_fields"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    PostAtsCandidatesCandidateIDTagsRequestBodyPostHeaders.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


GetAssessmentPackagesPositiveResponseType = Literal[
    "BEHAVIORAL",
    "VIDEO_INTERVIEW",
    "SKILLS_TEST",
    "BACKGROUND_CHECK",
    "REFERENCE_CHECK",
]


class GetAssessmentPackagesPositiveResponsePackageTypedDict(TypedDict):
    id: str
    name: str
    description: str
    updated_at: Nullable[datetime]
    r"""YYYY-MM-DDTHH:mm:ss.sssZ
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    type: Nullable[GetAssessmentPackagesPositiveResponseType]


class GetAssessmentPackagesPositiveResponsePackage(BaseModel):
    id: str

    name: str

    description: str

    updated_at: Nullable[datetime]
    r"""YYYY-MM-DDTHH:mm:ss.sssZ
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    type: Nullable[GetAssessmentPackagesPositiveResponseType]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetAssessmentPackagesPositiveResponseDataTypedDict(TypedDict):
    packages: List[GetAssessmentPackagesPositiveResponsePackageTypedDict]


class GetAssessmentPackagesPositiveResponseData(BaseModel):
    packages: List[GetAssessmentPackagesPositiveResponsePackage]


class GetAssessmentPackagesPositiveResponseTypedDict(TypedDict):
    data: GetAssessmentPackagesPositiveResponseDataTypedDict
    status: Literal["success"]


class GetAssessmentPackagesPositiveResponse(BaseModel):
    data: GetAssessmentPackagesPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    GetAssessmentPackagesPositiveResponse.model_rebuild()
except NameError:
    pass
